@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,9 +37,38 @@
 
 #include "StatCalc.h"
 #include "TimeA2.h"
+#include "util.h"
 
 namespace aria2 {
 
+class SizeFormatter:public std::unary_function<int64_t, std::string> {
+protected:
+  virtual std::string format(int64_t size) const = 0;
+public:
+  virtual ~SizeFormatter() {}
+
+  std::string operator()(int64_t size) const
+  {
+    return format(size);
+  }
+};
+
+class AbbrevSizeFormatter:public SizeFormatter {
+protected:
+  virtual std::string format(int64_t size) const
+  {
+    return util::abbrevSize(size);
+  }
+};
+
+class PlainSizeFormatter:public SizeFormatter {
+protected:
+  virtual std::string format(int64_t size) const
+  {
+    return util::itos(size);
+  }
+};
+
 class ConsoleStatCalc:public StatCalc
 {
 private:
@@ -48,8 +77,10 @@ private:
   Time _lastSummaryNotified;
 
   time_t _summaryInterval;
+
+  SharedHandle<SizeFormatter> _sizeFormatter;
 public:
-  ConsoleStatCalc(time_t summaryInterval);
+  ConsoleStatCalc(time_t summaryInterval, bool humanReadable = true);
 
   virtual ~ConsoleStatCalc() {}
 
