@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -47,7 +47,6 @@
 namespace aria2 {
 
 class Peer;
-class PeerStorage;
 
 class DHTPeerAnnounceEntry {
 private:
@@ -55,8 +54,6 @@ private:
 
   std::deque<PeerAddrEntry> _peerAddrEntries;
 
-  SharedHandle<PeerStorage> _peerStorage;
-
   Time _lastUpdated;
 public:
   DHTPeerAnnounceEntry(const unsigned char* infoHash);
@@ -67,13 +64,12 @@ public:
   // if it already exists, update "Last Updated" property.
   void addPeerAddrEntry(const PeerAddrEntry& entry);
 
-  void clearLocal();
-
-  void setPeerStorage(const SharedHandle<PeerStorage>& peerStorage);
-
   size_t countPeerAddrEntry() const;
 
-  const std::deque<PeerAddrEntry>& getPeerAddrEntries() const;
+  const std::deque<PeerAddrEntry>& getPeerAddrEntries() const
+  {
+    return _peerAddrEntries;
+  }
 
   void removeStalePeerAddrEntry(time_t timeout);
   
