@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -41,7 +41,6 @@
 
 namespace aria2 {
 
-class PeerStorage;
 class Peer;
 class DHTPeerAnnounceEntry;
 class DHTTaskQueue;
@@ -65,20 +64,12 @@ public:
   ~DHTPeerAnnounceStorage();
 
   void addPeerAnnounce(const unsigned char* infoHash,
-		       const std::string& ipaddr, uint16_t port);
-
-  // add peer announce as localhost downloading the content
-  void addPeerAnnounce(const unsigned char* infoHash,
-		       const SharedHandle<PeerStorage>& peerStorage);
-  
-  // Call DHTPeerAnnounceEntry::clearLocal() for infoHash if found.
-  // If DHTPeerAnnounceEntry is empty, it is erased.
-  void removeLocalPeerAnnounce(const unsigned char* infoHash);
+                       const std::string& ipaddr, uint16_t port);
 
   bool contains(const unsigned char* infoHash) const;
 
   void getPeers(std::deque<SharedHandle<Peer> >& peers,
-		const unsigned char* infoHash);
+                const unsigned char* infoHash);
 
   // drop peer announce entry which is not updated in the past
   // DHT_PEER_ANNOUNCE_PURGE_INTERVAL seconds.
