@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -52,7 +52,7 @@
 #include "DefaultDiskWriterFactory.h"
 #include "FileEntry.h"
 #include "DlAbortEx.h"
-#include "Util.h"
+#include "util.h"
 #include "a2functional.h"
 #include "Option.h"
 #include "StringFormat.h"
@@ -63,11 +63,11 @@
 namespace aria2 {
 
 DefaultPieceStorage::DefaultPieceStorage
-(const DownloadContextHandle& downloadContext, const Option* option):
+(const SharedHandle<DownloadContext>& downloadContext, const Option* option):
   downloadContext(downloadContext),
   bitfieldMan(BitfieldManFactory::getFactoryInstance()->
-	      createBitfieldMan(downloadContext->getPieceLength(),
-				downloadContext->getTotalLength())),
+              createBitfieldMan(downloadContext->getPieceLength(),
+                                downloadContext->getTotalLength())),
   _diskWriterFactory(new DefaultDiskWriterFactory()),
   endGamePieceNum(END_GAME_PIECE_NUM),
   logger(LogFactory::getInstance()),
@@ -80,30 +80,24 @@ DefaultPieceStorage::~DefaultPieceStorage() {
   delete bitfieldMan;
 }
 
-bool DefaultPieceStorage::hasMissingPiece(const PeerHandle& peer)
-{
-  return bitfieldMan->hasMissingPiece(peer->getBitfield(),
-				      peer->getBitfieldLength());
-}
-
 bool DefaultPieceStorage::isEndGame()
 {
   return bitfieldMan->countMissingBlock() <= endGamePieceNum;
 }
 
 bool DefaultPieceStorage::getMissingPieceIndex(size_t& index,
-					       const unsigned char* bitfield,
-					       size_t length)
+                                               const unsigned char* bitfield,
+                                               size_t length)
 {
   const size_t mislen = bitfieldMan->getBitfieldLength();
   array_ptr<unsigned char> misbitfield(new unsigned char[mislen]);
   bool r;
   if(isEndGame()) {
     r = bitfieldMan->getAllMissingIndexes(misbitfield, mislen,
-					  bitfield, length);
+                                          bitfield, length);
   } else {
     r = bitfieldMan->getAllMissingUnusedIndexes(misbitfield, mislen,
-						bitfield, length);
+                                                bitfield, length);
   }
   if(r) {
     // We assume indexes is sorted using comparator less.
@@ -146,7 +140,7 @@ PieceHandle DefaultPieceStorage::getPiece(size_t index)
     if(piece.isNull()) {
       piece.reset(new Piece(index, bitfieldMan->getBlockLength(index)));
       if(hasPiece(index)) {
-	piece->setAllBlock();
+        piece->setAllBlock();
       }
     }
   }
@@ -159,7 +153,7 @@ void DefaultPieceStorage::addUsedPiece(const PieceHandle& piece)
     std::lower_bound(usedPieces.begin(), usedPieces.end(), piece);
   usedPieces.insert(i, piece);
   logger->debug("usedPieces.size()=%lu",
-		static_cast<unsigned long>(usedPieces.size()));
+                static_cast<unsigned long>(usedPieces.size()));
 }
 
 PieceHandle DefaultPieceStorage::findUsedPiece(size_t index) const
@@ -194,6 +188,14 @@ SharedHandle<Piece> DefaultPieceStorage::getMissingPiece
   return getMissingPiece(bitfield.getBitfield(), bitfield.getBitfieldLength());
 }
 
+#ifdef ENABLE_BITTORRENT
+
+bool DefaultPieceStorage::hasMissingPiece(const PeerHandle& peer)
+{
+  return bitfieldMan->hasMissingPiece(peer->getBitfield(),
+                                      peer->getBitfieldLength());
+}
+
 PieceHandle DefaultPieceStorage::getMissingPiece(const SharedHandle<Peer>& peer)
 {
   return getMissingPiece(peer->getBitfield(), peer->getBitfieldLength());
@@ -203,7 +205,7 @@ void DefaultPieceStorage::createFastIndexBitfield
 (BitfieldMan& bitfield, const SharedHandle<Peer>& peer)
 {
   for(std::deque<size_t>::const_iterator itr =
-	peer->getPeerAllowedIndexSet().begin();
+        peer->getPeerAllowedIndexSet().begin();
       itr != peer->getPeerAllowedIndexSet().end(); ++itr) {
     if(!bitfieldMan->isBitSet(*itr) && peer->hasPiece(*itr)) {
       bitfield.setBit(*itr);
@@ -216,7 +218,7 @@ PieceHandle DefaultPieceStorage::getMissingFastPiece
 {
   if(peer->isFastExtensionEnabled() && peer->countPeerAllowedIndexSet() > 0) {
     BitfieldMan tempBitfield(bitfieldMan->getBlockLength(),
-			     bitfieldMan->getTotalLength());
+                             bitfieldMan->getTotalLength());
     createFastIndexBitfield(tempBitfield, peer);
     return getMissingPiece(tempBitfield);
   } else {
@@ -225,7 +227,7 @@ PieceHandle DefaultPieceStorage::getMissingFastPiece
 }
 
 static void unsetExcludedIndexes(BitfieldMan& bitfield,
-				 const std::deque<size_t>& excludedIndexes)
+                                 const std::deque<size_t>& excludedIndexes)
 {
   for(std::deque<size_t>::const_iterator i = excludedIndexes.begin();
       i != excludedIndexes.end(); ++i) {
@@ -237,7 +239,7 @@ SharedHandle<Piece> DefaultPieceStorage::getMissingPiece
 (const SharedHandle<Peer>& peer, const std::deque<size_t>& excludedIndexes)
 {
   BitfieldMan tempBitfield(bitfieldMan->getBlockLength(),
-			   bitfieldMan->getTotalLength());
+                           bitfieldMan->getTotalLength());
   tempBitfield.setBitfield(peer->getBitfield(), peer->getBitfieldLength());
   unsetExcludedIndexes(tempBitfield, excludedIndexes);
   return getMissingPiece(tempBitfield);
@@ -248,7 +250,7 @@ SharedHandle<Piece> DefaultPieceStorage::getMissingFastPiece
 {
   if(peer->isFastExtensionEnabled() && peer->countPeerAllowedIndexSet() > 0) {
     BitfieldMan tempBitfield(bitfieldMan->getBlockLength(),
-			     bitfieldMan->getTotalLength());
+                             bitfieldMan->getTotalLength());
     createFastIndexBitfield(tempBitfield, peer);
     unsetExcludedIndexes(tempBitfield, excludedIndexes);
     return getMissingPiece(tempBitfield);
@@ -257,10 +259,19 @@ SharedHandle<Piece> DefaultPieceStorage::getMissingFastPiece
   }
 }
 
-PieceHandle DefaultPieceStorage::getMissingPiece()
+#endif // ENABLE_BITTORRENT
+
+bool DefaultPieceStorage::hasMissingUnusedPiece()
 {
   size_t index;
-  if(bitfieldMan->getSparseMissingUnusedIndex(index)) {
+  return bitfieldMan->getFirstMissingUnusedIndex(index);
+}
+
+PieceHandle DefaultPieceStorage::getSparseMissingUnusedPiece
+(const unsigned char* ignoreBitfield, size_t length)
+{
+  size_t index;
+  if(bitfieldMan->getSparseMissingUnusedIndex(index, ignoreBitfield, length)) {
     return checkOutPiece(index);
   } else {
     return SharedHandle<Piece>();
@@ -303,7 +314,7 @@ void DefaultPieceStorage::deleteUsedPiece(const PieceHandle& piece)
 // }
 
 // size_t DefaultPieceStorage::deleteUsedPiecesByFillRate(int fillRate,
-// 						       size_t delNum)
+//                                                     size_t delNum)
 // {
 //   size_t deleted = 0;
 //   for(Pieces::iterator itr = usedPieces.begin();
@@ -312,9 +323,9 @@ void DefaultPieceStorage::deleteUsedPiece(const PieceHandle& piece)
 //     if(!bitfieldMan->isUseBitSet(piece->getIndex()) &&
 //        piece->countCompleteBlock() <= piece->countBlock()*(fillRate/100.0)) {
 //       logger->info(MSG_DELETING_USED_PIECE,
-// 		    piece->getIndex(),
-// 		    (piece->countCompleteBlock()*100)/piece->countBlock(),
-// 		    fillRate);
+//                  piece->getIndex(),
+//                  (piece->countCompleteBlock()*100)/piece->countBlock(),
+//                  fillRate);
 //       itr = usedPieces.erase(itr);
 //       ++deleted;
 //     } else {
@@ -330,9 +341,9 @@ void DefaultPieceStorage::completePiece(const PieceHandle& piece)
     return;
   }
   deleteUsedPiece(piece);
-//   if(!isEndGame()) {
-//     reduceUsedPieces(100);
-//   }
+  //   if(!isEndGame()) {
+  //     reduceUsedPieces(100);
+  //   }
   if(allDownloadFinished()) {
     return;
   }
@@ -341,7 +352,6 @@ void DefaultPieceStorage::completePiece(const PieceHandle& piece)
   addPieceStats(piece->getIndex());
   if(downloadFinished()) {
     downloadContext->resetDownloadStopTime();
-    diskAdaptor->onDownloadComplete();
     if(isSelectiveDownloadingMode()) {
       logger->notice(MSG_SELECTIVE_DOWNLOAD_COMPLETED);
       // following line was commented out in order to stop sending request
@@ -358,12 +368,6 @@ bool DefaultPieceStorage::isSelectiveDownloadingMode()
   return bitfieldMan->isFilterEnabled();
 }
 
-void DefaultPieceStorage::finishSelectiveDownloadingMode()
-{
-  bitfieldMan->clearFilter();
-  diskAdaptor->addAllDownloadEntry();
-}
-
 // not unittested
 void DefaultPieceStorage::cancelPiece(const PieceHandle& piece)
 {
@@ -420,46 +424,34 @@ size_t DefaultPieceStorage::getInFlightPieceCompletedLength() const
 }
 
 // not unittested
-void DefaultPieceStorage::setFileFilter(const std::deque<std::string>& filePaths)
+void DefaultPieceStorage::setupFileFilter()
 {
-  if(downloadContext->getFileMode() != DownloadContext::MULTI || filePaths.empty()) {
+  const std::vector<SharedHandle<FileEntry> >& fileEntries =
+    downloadContext->getFileEntries();
+  bool allSelected = true;
+  for(std::vector<SharedHandle<FileEntry> >::const_iterator i =
+        fileEntries.begin(); i != fileEntries.end(); ++i) {
+    if(!(*i)->isRequested()) {
+      allSelected = false;
+      break;
+    }
+  }
+  if(allSelected) {
     return;
   }
-  diskAdaptor->removeAllDownloadEntry();
-  for(std::deque<std::string>::const_iterator pitr = filePaths.begin();
-      pitr != filePaths.end(); pitr++) {
-    if(!diskAdaptor->addDownloadEntry(*pitr)) {
-      throw DlAbortEx(StringFormat(EX_NO_SUCH_FILE_ENTRY, (*pitr).c_str()).str());
+  for(std::vector<SharedHandle<FileEntry> >::const_iterator i =
+        fileEntries.begin(); i != fileEntries.end(); ++i) {
+    if((*i)->isRequested()) {
+      bitfieldMan->addFilter((*i)->getOffset(), (*i)->getLength());
     }
-    FileEntryHandle fileEntry = diskAdaptor->getFileEntryFromPath(*pitr);
-    bitfieldMan->addFilter(fileEntry->getOffset(), fileEntry->getLength());
   }
   bitfieldMan->enableFilter();
 }
 
-void DefaultPieceStorage::setFileFilter(IntSequence seq)
-{
-  std::deque<int32_t> fileIndexes = seq.flush();
-  // TODO Is sorting necessary?
-  std::sort(fileIndexes.begin(), fileIndexes.end());
-  fileIndexes.erase(std::unique(fileIndexes.begin(), fileIndexes.end()), fileIndexes.end());
-  std::deque<std::string> filePaths;
-  const FileEntries& entries = diskAdaptor->getFileEntries();
-  int32_t entriesSize = entries.size();
-  for(int32_t i = 0; i < entriesSize; i++) {
-    if(std::find(fileIndexes.begin(), fileIndexes.end(), i+1) != fileIndexes.end()) {
-      logger->debug("index=%d is %s", i+1, entries[i]->getPath().c_str());
-      filePaths.push_back(entries[i]->getPath());
-    }
-  }
-  setFileFilter(filePaths);
-}
-
 // not unittested
 void DefaultPieceStorage::clearFileFilter()
 {
   bitfieldMan->clearFilter();
-  diskAdaptor->addAllDownloadEntry();
 }
 
 // not unittested
@@ -478,11 +470,12 @@ bool DefaultPieceStorage::allDownloadFinished()
 // not unittested
 void DefaultPieceStorage::initStorage()
 {
-  if(downloadContext->getFileMode() == DownloadContext::SINGLE) {
+  if(downloadContext->getFileEntries().size() == 1) {
     logger->debug("Instantiating DirectDiskAdaptor");
     DirectDiskAdaptorHandle directDiskAdaptor(new DirectDiskAdaptor());
     directDiskAdaptor->setTotalLength(downloadContext->getTotalLength());
-    directDiskAdaptor->setFileEntries(downloadContext->getFileEntries());
+    directDiskAdaptor->setFileEntries(downloadContext->getFileEntries().begin(),
+                                      downloadContext->getFileEntries().end());
 
     DiskWriterHandle writer =
       _diskWriterFactory->newDiskWriter(directDiskAdaptor->getFilePath());
@@ -493,10 +486,10 @@ void DefaultPieceStorage::initStorage()
     directDiskAdaptor->setDiskWriter(writer);
     this->diskAdaptor = directDiskAdaptor;
   } else {
-    // file mode == DownloadContext::MULTI
     logger->debug("Instantiating MultiDiskAdaptor");
     MultiDiskAdaptorHandle multiDiskAdaptor(new MultiDiskAdaptor());
-    multiDiskAdaptor->setFileEntries(downloadContext->getFileEntries());
+    multiDiskAdaptor->setFileEntries(downloadContext->getFileEntries().begin(),
+                                     downloadContext->getFileEntries().end());
     if(option->getAsBool(PREF_ENABLE_DIRECT_IO)) {
       multiDiskAdaptor->allowDirectIO();
     }
@@ -512,7 +505,7 @@ void DefaultPieceStorage::initStorage()
 }
 
 void DefaultPieceStorage::setBitfield(const unsigned char* bitfield,
-				      size_t bitfieldLength)
+                                      size_t bitfieldLength)
 {
   bitfieldMan->setBitfield(bitfield, bitfieldLength);
   addPieceStats(bitfield, bitfieldLength);
@@ -545,8 +538,8 @@ void DefaultPieceStorage::advertisePiece(int32_t cuid, size_t index)
 
 void
 DefaultPieceStorage::getAdvertisedPieceIndexes(std::deque<size_t>& indexes,
-					       int32_t myCuid,
-					       const Time& lastCheckTime)
+                                               int32_t myCuid,
+                                               const Time& lastCheckTime)
 {
   for(Haves::const_iterator itr = haves.begin(); itr != haves.end(); itr++) {
     const Haves::value_type& have = *itr;
@@ -605,7 +598,7 @@ void DefaultPieceStorage::markPiecesDone(uint64_t length)
       PieceHandle p(new Piece(numPiece, bitfieldMan->getBlockLength(numPiece)));
       
       for(size_t i = 0; i < r; ++i) {
-	p->completeBlock(i);
+        p->completeBlock(i);
       }
 
 #ifdef ENABLE_MESSAGE_DIGEST
@@ -646,23 +639,23 @@ void DefaultPieceStorage::setDiskWriterFactory(const DiskWriterFactoryHandle& di
 }
 
 void DefaultPieceStorage::addPieceStats(const unsigned char* bitfield,
-					size_t bitfieldLength)
+                                        size_t bitfieldLength)
 {
   _pieceStatMan->addPieceStats(bitfield, bitfieldLength);
 }
 
 void DefaultPieceStorage::subtractPieceStats(const unsigned char* bitfield,
-					     size_t bitfieldLength)
+                                             size_t bitfieldLength)
 {
   _pieceStatMan->subtractPieceStats(bitfield, bitfieldLength);
 }
 
 void DefaultPieceStorage::updatePieceStats(const unsigned char* newBitfield,
-					   size_t newBitfieldLength,
-					   const unsigned char* oldBitfield)
+                                           size_t newBitfieldLength,
+                                           const unsigned char* oldBitfield)
 {
   _pieceStatMan->updatePieceStats(newBitfield, newBitfieldLength,
-				   oldBitfield);
+                                  oldBitfield);
 }
 
 void DefaultPieceStorage::addPieceStats(size_t index)
