@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -39,11 +39,11 @@
 #include <utime.h>
 #include <unistd.h>
 
-#include <deque>
+#include <vector>
 #include <cstring>
 #include <cstdio>
 
-#include "Util.h"
+#include "util.h"
 #include "A2STR.h"
 #include "array_fun.h"
 
@@ -59,7 +59,7 @@ File::File(const std::string& name):name(name) {}
 File::~File() {}
 
 int File::fillStat(a2_struct_stat& fstat) {
-  return stat(name.c_str(), &fstat);
+  return a2stat(name.c_str(), &fstat);
 }
 
 bool File::exists() {
@@ -105,18 +105,18 @@ bool File::mkdirs() {
   if(isDir()) {
     return false;
   }
-  std::deque<std::string> dirs;
-  Util::slice(dirs, name, '/');
+  std::vector<std::string> dirs;
+  util::split(name, std::back_inserter(dirs), "/");
   if(!dirs.size()) {
     return true;
   }
 
   std::string accDir;
-  if(Util::startsWith(name, A2STR::SLASH_C)) {
+  if(util::startsWith(name, A2STR::SLASH_C)) {
     accDir = A2STR::SLASH_C;
   }
-  for(std::deque<std::string>::const_iterator itr = dirs.begin(); itr != dirs.end();
-      ++itr, accDir += A2STR::SLASH_C) {
+  for(std::vector<std::string>::const_iterator itr = dirs.begin();
+      itr != dirs.end(); ++itr, accDir += A2STR::SLASH_C) {
     accDir += *itr;
     if(File(accDir).isDir()) {
       continue;
