@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -41,21 +41,25 @@
 #include "HttpHeaderProcessor.h"
 #include "DlAbortEx.h"
 #include "message.h"
-#include "Util.h"
+#include "util.h"
 #include "LogFactory.h"
 #include "Logger.h"
 #include "Base64.h"
+#include "a2functional.h"
 
 namespace aria2 {
 
 HttpServer::HttpServer(const SharedHandle<SocketCore>& socket,
-		       DownloadEngine* e):
+                       DownloadEngine* e):
   _socket(socket),
   _socketBuffer(socket),
   _e(e),
   _headerProcessor(new HttpHeaderProcessor()),
   _logger(LogFactory::getInstance()),
-  _keepAlive(true)
+  _keepAlive(true),
+  _gzip(false),
+  _acceptsPersistentConnection(true),
+  _acceptsGZip(false)
 {}
 
 HttpServer::~HttpServer() {}
@@ -80,15 +84,28 @@ SharedHandle<HttpHeader> HttpServer::receiveRequest()
   SharedHandle<HttpHeader> header = _headerProcessor->getHttpRequestHeader();
   if(!header.isNull()) {
     _logger->info("HTTP Server received request\n%s",
-		  _headerProcessor->getHeaderString().c_str());
+                  _headerProcessor->getHeaderString().c_str());
     _lastRequestHeader = header;
     _lastBody.clear();
     _lastBody.str("");
     _lastContentLength =
       _lastRequestHeader->getFirstAsUInt(HttpHeader::CONTENT_LENGTH);
     _headerProcessor->clear();
-  }
 
+    std::string connection =
+      util::toLower(_lastRequestHeader->getFirst(HttpHeader::CONNECTION));
+    _acceptsPersistentConnection =
+      connection.find(HttpHeader::CLOSE) == std::string::npos &&
+      (_lastRequestHeader->getVersion() == HttpHeader::HTTP_1_1 ||
+       connection.find("keep-alive") != std::string::npos);
+
+    std::vector<std::string> acceptEncodings;
+    util::split(_lastRequestHeader->getFirst(HttpHeader::ACCEPT_ENCODING),
+                std::back_inserter(acceptEncodings), A2STR::COMMA_C, true);
+    _acceptsGZip =
+      std::find(acceptEncodings.begin(), acceptEncodings.end(), "gzip")
+      != acceptEncodings.end();
+  }
   return header;
 }
 
@@ -100,8 +117,8 @@ bool HttpServer::receiveBody()
   const size_t BUFLEN = 4096;
   char buf[BUFLEN];
   size_t length = std::min(BUFLEN,
-			   static_cast<size_t>
-			   (_lastContentLength-_lastBody.tellg()));
+                           static_cast<size_t>
+                           (_lastContentLength-_lastBody.tellg()));
   _socket->readData(buf, length);
   if(length == 0 && !(_socket->wantRead() || _socket->wantWrite())) {
     throw DL_ABORT_EX(EX_EOF_FROM_PEER);
@@ -120,40 +137,29 @@ const std::string& HttpServer::getRequestPath() const
   return _lastRequestHeader->getRequestPath();
 }
 
-bool HttpServer::supportsPersistentConnection() const
-{
-  if(!_keepAlive) {
-    return false;
-  }
-
-  std::string connection =
-    Util::toLower(_lastRequestHeader->getFirst(HttpHeader::CONNECTION));
-
-  return connection.find(HttpHeader::CLOSE) == std::string::npos &&
-    (_lastRequestHeader->getVersion() == HttpHeader::HTTP_1_1 ||
-     connection.find("keep-alive") != std::string::npos);
-}
-
 void HttpServer::feedResponse(const std::string& text, const std::string& contentType)
 {
   feedResponse("200 OK", "", text, contentType);
 }
 
 void HttpServer::feedResponse(const std::string& status,
-			      const std::string& headers,
-			      const std::string& text,
-			      const std::string& contentType)
+                              const std::string& headers,
+                              const std::string& text,
+                              const std::string& contentType)
 {
-  std::string header = "HTTP/1.1 "+status+"\r\n"
-    "Content-Type: "+contentType+"\r\n"
-    "Content-Length: "+Util::uitos(text.size())+"\r\n";
-
+  std::string header = "HTTP/1.1 ";
+  strappend(header, status, "\r\n",
+            "Content-Type: ", contentType, "\r\n",
+            "Content-Length: ", util::uitos(text.size()), "\r\n");
+  if(supportsGZip()) {
+    header += "Content-Encoding: gzip\r\n";
+  }
   if(!supportsPersistentConnection()) {
     header += "Connection: close\r\n";
   }
   if(!headers.empty()) {
     header += headers;
-    if(!Util::endsWith(headers, "\r\n")) {
+    if(!util::endsWith(headers, "\r\n")) {
       header += "\r\n";
     }
   }
@@ -161,7 +167,7 @@ void HttpServer::feedResponse(const std::string& status,
   header += "\r\n";
 
   _logger->debug("HTTP Server sends response:\n%s", header.c_str());
-		 
+                 
   _socketBuffer.feedSendBuffer(header);
   _socketBuffer.feedSendBuffer(text);
 }
@@ -186,12 +192,12 @@ bool HttpServer::authenticate()
   if(authHeader.empty()) {
     return false;
   }
-  std::pair<std::string, std::string> p = Util::split(authHeader, " ");
+  std::pair<std::string, std::string> p = util::split(authHeader, " ");
   if(p.first != "Basic") {
     return false;
   }
   std::string userpass = Base64::decode(p.second);
-  std::pair<std::string, std::string> userpassPair = Util::split(userpass, ":");
+  std::pair<std::string, std::string> userpassPair = util::split(userpass, ":");
   return _username == userpassPair.first && _password == userpassPair.second;
 }
 
