@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,6 +37,8 @@
 
 #include "DiskAdaptor.h"
 
+#include <deque>
+
 namespace aria2 {
 
 class MultiFileAllocationIterator;
@@ -65,17 +67,26 @@ public:
 
   void closeFile();
 
-  bool isOpen() const;
+  bool isOpen() const
+  {
+    return _open;
+  }
 
   bool fileExists();
 
   uint64_t size() const;
 
-  SharedHandle<FileEntry> getFileEntry() const;
+  const SharedHandle<FileEntry>& getFileEntry() const
+  {
+    return fileEntry;
+  }
 
   void setDiskWriter(const SharedHandle<DiskWriter>& diskWriter);
 
-  SharedHandle<DiskWriter> getDiskWriter() const;
+  const SharedHandle<DiskWriter>& getDiskWriter() const
+  {
+    return diskWriter;
+  }
 
   bool operator<(const DiskWriterEntry& entry) const;
 
@@ -89,14 +100,21 @@ public:
   // called.
   void disableDirectIO();
 
-  bool needsFileAllocation() const;
+  bool needsFileAllocation() const
+  {
+    return _needsFileAllocation;
+  }
+
+  void needsFileAllocation(bool f)
+  {
+    _needsFileAllocation = f;
+  }
 
-  void needsFileAllocation(bool f);
 };
 
 typedef SharedHandle<DiskWriterEntry> DiskWriterEntryHandle;
 
-typedef std::deque<DiskWriterEntryHandle> DiskWriterEntries;
+typedef std::vector<DiskWriterEntryHandle> DiskWriterEntries;
 
 class MultiDiskAdaptor : public DiskAdaptor {
   friend class MultiFileAllocationIterator;
@@ -104,7 +122,7 @@ private:
   size_t pieceLength;
   DiskWriterEntries diskWriterEntries;
 
-  std::deque<SharedHandle<DiskWriterEntry> > _openedDiskWriterEntries;
+  std::vector<SharedHandle<DiskWriterEntry> > _openedDiskWriterEntries;
 
   size_t _maxOpenFiles;
 
@@ -117,7 +135,7 @@ private:
   void mkdir() const;
 
   void openIfNot(const SharedHandle<DiskWriterEntry>& entry,
-		 void (DiskWriterEntry::*f)());
+                 void (DiskWriterEntry::*f)());
  
   static const size_t DEFAULT_MAX_OPEN_FILES = 100;
 
@@ -134,10 +152,8 @@ public:
 
   virtual void closeFile();
 
-  virtual void onDownloadComplete();
-
   virtual void writeData(const unsigned char* data, size_t len,
-			 off_t offset);
+                         off_t offset);
 
   virtual ssize_t readData(unsigned char* data, size_t len, off_t offset);
 
@@ -176,8 +192,12 @@ public:
 
   virtual size_t utime(const Time& actime, const Time& modtime);
 
-  const std::deque<SharedHandle<DiskWriterEntry> >&
-  getDiskWriterEntries() const;
+  const std::vector<SharedHandle<DiskWriterEntry> >&
+  getDiskWriterEntries() const
+  {
+    return diskWriterEntries;
+  }
+
 };
 
 typedef SharedHandle<MultiDiskAdaptor> MultiDiskAdaptorHandle;
