@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -44,8 +44,9 @@
 #include <iterator>
 
 #include "A2STR.h"
-#include "Util.h"
+#include "util.h"
 #include "OptionHandlerException.h"
+#include "a2functional.h"
 
 #define NO_DESCRIPTION A2STR::NIL
 #define NO_DEFAULT_VALUE A2STR::NIL
@@ -75,10 +76,10 @@ protected:
   virtual void parseArg(Option& option, const std::string& arg) = 0;
 public:
   NameMatchOptionHandler(const std::string& optName,
-			 const std::string& description = NO_DESCRIPTION,
-			 const std::string& defaultValue = NO_DEFAULT_VALUE,
-			 ARG_TYPE argType = REQ_ARG,
-			 char shortName = 0):
+                         const std::string& description = NO_DESCRIPTION,
+                         const std::string& defaultValue = NO_DEFAULT_VALUE,
+                         ARG_TYPE argType = REQ_ARG,
+                         char shortName = 0):
     _optName(optName),
     _description(description),
     _defaultValue(defaultValue),
@@ -99,7 +100,7 @@ public:
     try {
       parseArg(option, arg);
     } catch(Exception& e) {
-      throw OptionHandlerException(_optName, e);
+      throw OPTION_HANDLER_EXCEPTION2(_optName, e);
     }
   }
 
@@ -115,10 +116,7 @@ public:
 
   virtual std::string toTagString() const
   {
-    std::stringstream s;
-    std::copy(_tags.begin(), _tags.end(),
-	      std::ostream_iterator<std::string>(s, ","));
-    return Util::trim(s.str(), ", ");
+    return strjoin(_tags.begin(), _tags.end(), ", ");
   }
 
   virtual const std::string& getName() const
