@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -176,6 +176,12 @@ extern const std::string PREF_ON_DOWNLOAD_COMPLETE;
 extern const std::string PREF_ON_DOWNLOAD_ERROR;
 // value: true | false
 extern const std::string PREF_XML_RPC_LISTEN_ALL;
+// value: string
+extern const std::string PREF_INTERFACE;
+// value: true | false
+extern const std::string PREF_DISABLE_IPV6;
+// value: true | false
+extern const std::string PREF_HUMAN_READABLE;
 
 /**
  * FTP related preferences
@@ -196,9 +202,6 @@ extern const std::string PREF_FTP_REUSE_CONNECTION;
  */
 extern const std::string PREF_HTTP_USER;
 extern const std::string PREF_HTTP_PASSWD;
-// values: basic
-extern const std::string PREF_HTTP_AUTH_SCHEME;
-extern const std::string V_BASIC;
 // values: string
 extern const std::string PREF_USER_AGENT;
 // value: string that your file system recognizes as a file name.
@@ -225,6 +228,8 @@ extern const std::string PREF_CHECK_CERTIFICATE;
 extern const std::string PREF_USE_HEAD;
 // value: true | false
 extern const std::string PREF_HTTP_AUTH_CHALLENGE;
+// value: true | false
+extern const std::string PREF_HTTP_NO_CACHE;
 
 /**;
  * Proxy related preferences
@@ -309,6 +314,12 @@ extern const std::string PREF_INDEX_OUT;
 extern const std::string PREF_BT_TRACKER_INTERVAL;
 // values: 1*digit
 extern const std::string PREF_BT_STOP_TIMEOUT;
+// values: head[=SIZE]|tail[=SIZE], ...
+extern const std::string PREF_BT_PRIORITIZE_PIECE;
+// values: true | false
+extern const std::string PREF_BT_SAVE_METADATA;
+// values: true | false
+extern const std::string PREF_BT_METADATA_ONLY;
 
 /**
  * Metalink related preferences
