@@ -13,7 +13,7 @@
 #include "array_fun.h"
 #include "prefs.h"
 #include "Exception.h"
-#include "Util.h"
+#include "util.h"
 
 namespace aria2 {
 
@@ -82,7 +82,7 @@ void DownloadHelperTest::testCreateRequestGroupForUri()
     CPPUNIT_ASSERT_EQUAL((size_t)1, result.size());
     SharedHandle<RequestGroup> group = result[0];
     std::deque<std::string> uris;
-    group->getURIs(uris);
+    group->getDownloadContext()->getFirstFileEntry()->getUris(uris);
     CPPUNIT_ASSERT_EQUAL((size_t)3, uris.size());
     for(size_t i = 0; i < arrayLength(array); ++i) {
       CPPUNIT_ASSERT_EQUAL(array[i], uris[i]);
@@ -90,8 +90,7 @@ void DownloadHelperTest::testCreateRequestGroupForUri()
     CPPUNIT_ASSERT_EQUAL((unsigned int)3, group->getNumConcurrentCommand());
     SharedHandle<DownloadContext> ctx = group->getDownloadContext();
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp"), ctx->getDir());
-    CPPUNIT_ASSERT_EQUAL(std::string("/tmp/file.out"),
-			 ctx->getActualBasePath());
+    CPPUNIT_ASSERT_EQUAL(std::string("/tmp/file.out"), ctx->getBasePath());
   }
   _option->put(PREF_SPLIT, "5");
   {
@@ -102,7 +101,7 @@ void DownloadHelperTest::testCreateRequestGroupForUri()
     CPPUNIT_ASSERT_EQUAL((size_t)1, result.size());
     SharedHandle<RequestGroup> group = result[0];
     std::deque<std::string> uris;
-    group->getURIs(uris);
+    group->getDownloadContext()->getFirstFileEntry()->getUris(uris);
     CPPUNIT_ASSERT_EQUAL((size_t)5, uris.size());
     for(size_t i = 0; i < arrayLength(array); ++i) {
       CPPUNIT_ASSERT_EQUAL(array[i], uris[i]);
@@ -121,7 +120,7 @@ void DownloadHelperTest::testCreateRequestGroupForUri()
     CPPUNIT_ASSERT_EQUAL((size_t)1, result.size());
     SharedHandle<RequestGroup> group = result[0];
     std::deque<std::string> uris;
-    group->getURIs(uris);
+    group->getDownloadContext()->getFirstFileEntry()->getUris(uris);
     CPPUNIT_ASSERT_EQUAL((size_t)3, uris.size());
     for(size_t i = 0; i < arrayLength(array); ++i) {
       CPPUNIT_ASSERT_EQUAL(array[i], uris[i]);
@@ -139,17 +138,17 @@ void DownloadHelperTest::testCreateRequestGroupForUri()
     // for alpha server
     SharedHandle<RequestGroup> alphaGroup = result[0];
     std::deque<std::string> alphaURIs;
-    alphaGroup->getURIs(alphaURIs);
+    alphaGroup->getDownloadContext()->getFirstFileEntry()->getUris(alphaURIs);
     CPPUNIT_ASSERT_EQUAL((size_t)2, alphaURIs.size());
     for(size_t i = 0; i < 2; ++i) {
       CPPUNIT_ASSERT_EQUAL(array[0], uris[0]);
     }
     CPPUNIT_ASSERT_EQUAL((unsigned int)2,
-			 alphaGroup->getNumConcurrentCommand());
+                         alphaGroup->getNumConcurrentCommand());
     SharedHandle<DownloadContext> alphaCtx = alphaGroup->getDownloadContext();
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp"), alphaCtx->getDir());
     // See filename is not assigned yet
-    CPPUNIT_ASSERT_EQUAL(std::string(""), alphaCtx->getActualBasePath());
+    CPPUNIT_ASSERT_EQUAL(std::string(""), alphaCtx->getBasePath());
   }
 }
 
@@ -172,7 +171,7 @@ void DownloadHelperTest::testCreateRequestGroupForUri_parameterized()
     CPPUNIT_ASSERT_EQUAL((size_t)1, result.size());
     SharedHandle<RequestGroup> group = result[0];
     std::deque<std::string> uris;
-    group->getURIs(uris);
+    group->getDownloadContext()->getFirstFileEntry()->getUris(uris);
     CPPUNIT_ASSERT_EQUAL((size_t)3, uris.size());
 
     CPPUNIT_ASSERT_EQUAL(std::string("http://alpha/file"), uris[0]);
@@ -182,8 +181,7 @@ void DownloadHelperTest::testCreateRequestGroupForUri_parameterized()
     CPPUNIT_ASSERT_EQUAL((unsigned int)3, group->getNumConcurrentCommand());
     SharedHandle<DownloadContext> ctx = group->getDownloadContext();
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp"), ctx->getDir());
-    CPPUNIT_ASSERT_EQUAL(std::string("/tmp/file.out"),
-			 ctx->getActualBasePath());
+    CPPUNIT_ASSERT_EQUAL(std::string("/tmp/file.out"), ctx->getBasePath());
   }
 }
 
@@ -208,7 +206,7 @@ void DownloadHelperTest::testCreateRequestGroupForUri_BitTorrent()
     CPPUNIT_ASSERT_EQUAL((size_t)2, result.size());
     SharedHandle<RequestGroup> group = result[0];
     std::deque<std::string> uris;
-    group->getURIs(uris);
+    group->getDownloadContext()->getFirstFileEntry()->getUris(uris);
     CPPUNIT_ASSERT_EQUAL((size_t)3, uris.size());
 
     CPPUNIT_ASSERT_EQUAL(array[0], uris[0]);
@@ -219,18 +217,18 @@ void DownloadHelperTest::testCreateRequestGroupForUri_BitTorrent()
     SharedHandle<DownloadContext> ctx = group->getDownloadContext();
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp"), ctx->getDir());
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp/file.out"),
-			 ctx->getActualBasePath());
+                         ctx->getBasePath());
 
     SharedHandle<RequestGroup> torrentGroup = result[1];
     std::deque<std::string> auxURIs;
-    torrentGroup->getURIs(auxURIs);
+    torrentGroup->getDownloadContext()->getFirstFileEntry()->getUris(auxURIs);
     CPPUNIT_ASSERT(auxURIs.empty());
     CPPUNIT_ASSERT_EQUAL((unsigned int)3,
-			 torrentGroup->getNumConcurrentCommand());
+                         torrentGroup->getNumConcurrentCommand());
     SharedHandle<DownloadContext> btctx = torrentGroup->getDownloadContext();
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp"), btctx->getDir());
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp/aria2-test"),
-			 btctx->getActualBasePath());    
+                         btctx->getBasePath());    
   }
 }
 #endif // ENABLE_BITTORRENT
@@ -264,7 +262,7 @@ void DownloadHelperTest::testCreateRequestGroupForUri_Metalink()
 
     SharedHandle<RequestGroup> group = result[0];
     std::deque<std::string> uris;
-    group->getURIs(uris);
+    group->getDownloadContext()->getFirstFileEntry()->getUris(uris);
     CPPUNIT_ASSERT_EQUAL((size_t)3, uris.size());
     for(size_t i = 0; i < 3; ++i) {
       CPPUNIT_ASSERT_EQUAL(array[i], uris[i]);
@@ -273,20 +271,20 @@ void DownloadHelperTest::testCreateRequestGroupForUri_Metalink()
     SharedHandle<DownloadContext> ctx = group->getDownloadContext();
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp"), ctx->getDir());
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp/file.out"),
-			 ctx->getActualBasePath());
+                         ctx->getBasePath());
 
     SharedHandle<RequestGroup> aria2052Group = result[1];
     CPPUNIT_ASSERT_EQUAL((unsigned int)1, // because of maxconnections attribute
-			 aria2052Group->getNumConcurrentCommand());
+                         aria2052Group->getNumConcurrentCommand());
     SharedHandle<DownloadContext> aria2052Ctx =
       aria2052Group->getDownloadContext();
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp"), aria2052Ctx->getDir());
     CPPUNIT_ASSERT_EQUAL(std::string("/tmp/aria2-0.5.2.tar.bz2"),
-			 aria2052Ctx->getActualBasePath());
+                         aria2052Ctx->getBasePath());
     
     SharedHandle<RequestGroup> aria2051Group = result[2];
     CPPUNIT_ASSERT_EQUAL((unsigned int)2,
-			 aria2051Group->getNumConcurrentCommand());
+                         aria2051Group->getNumConcurrentCommand());
   }
 }
 #endif // ENABLE_METALINK
@@ -306,7 +304,7 @@ void DownloadHelperTest::testCreateRequestGroupForUriList()
 
   SharedHandle<RequestGroup> fileGroup = result[0];
   std::deque<std::string> fileURIs;
-  fileGroup->getURIs(fileURIs);
+  fileGroup->getDownloadContext()->getFirstFileEntry()->getUris(fileURIs);
   CPPUNIT_ASSERT_EQUAL(std::string("http://alpha/file"), fileURIs[0]);
   CPPUNIT_ASSERT_EQUAL(std::string("http://bravo/file"), fileURIs[1]);
   CPPUNIT_ASSERT_EQUAL(std::string("http://charlie/file"), fileURIs[2]);
@@ -314,13 +312,13 @@ void DownloadHelperTest::testCreateRequestGroupForUriList()
   SharedHandle<DownloadContext> fileCtx = fileGroup->getDownloadContext();
   CPPUNIT_ASSERT_EQUAL(std::string("/mydownloads"), fileCtx->getDir());
   CPPUNIT_ASSERT_EQUAL(std::string("/mydownloads/myfile.out"),
-		       fileCtx->getActualBasePath());
+                       fileCtx->getBasePath());
 
   SharedHandle<RequestGroup> fileISOGroup = result[1];
   SharedHandle<DownloadContext> fileISOCtx = fileISOGroup->getDownloadContext();
   CPPUNIT_ASSERT_EQUAL(std::string("/tmp"), fileISOCtx->getDir());
   CPPUNIT_ASSERT_EQUAL(std::string("/tmp/file.out"),
-		       fileISOCtx->getActualBasePath());
+                       fileISOCtx->getBasePath());
 }
 
 #ifdef ENABLE_BITTORRENT
@@ -346,13 +344,11 @@ void DownloadHelperTest::testCreateRequestGroupForBitTorrent()
 
     SharedHandle<RequestGroup> group = result[0];
     std::deque<std::string> uris;
-    group->getURIs(uris);
-    CPPUNIT_ASSERT_EQUAL((size_t)5, uris.size());
+    group->getDownloadContext()->getFirstFileEntry()->getUris(uris);
+    // See -s option is ignored
+    CPPUNIT_ASSERT_EQUAL((size_t)3, uris.size());
     for(size_t i = 0; i < arrayLength(array); ++i) {
-      CPPUNIT_ASSERT_EQUAL(array[i], uris[i]);
-    }
-    for(size_t i = 0; i < 5-arrayLength(array); ++i) {
-      CPPUNIT_ASSERT_EQUAL(array[i], uris[i+arrayLength(array)]);
+      CPPUNIT_ASSERT_EQUAL(array[i]+"/aria2-test/aria2/src/aria2c", uris[i]);
     }
     CPPUNIT_ASSERT_EQUAL((unsigned int)5, group->getNumConcurrentCommand());
   }
@@ -365,7 +361,7 @@ void DownloadHelperTest::testCreateRequestGroupForBitTorrent()
     CPPUNIT_ASSERT_EQUAL((size_t)1, result.size());
     SharedHandle<RequestGroup> group = result[0];
     std::deque<std::string> uris;
-    group->getURIs(uris);
+    group->getDownloadContext()->getFirstFileEntry()->getUris(uris);
     CPPUNIT_ASSERT_EQUAL((size_t)0, uris.size());
   }
   _option->put(PREF_FORCE_SEQUENTIAL, V_TRUE);
@@ -400,13 +396,13 @@ void DownloadHelperTest::testCreateRequestGroupForMetalink()
 #endif // !ENABLE_BITTORRENT
     SharedHandle<RequestGroup> group = result[0];
     std::deque<std::string> uris;
-    group->getURIs(uris);
+    group->getDownloadContext()->getFirstFileEntry()->getUris(uris);
     std::sort(uris.begin(), uris.end());
     CPPUNIT_ASSERT_EQUAL((size_t)2, uris.size());
     CPPUNIT_ASSERT_EQUAL(std::string("ftp://ftphost/aria2-0.5.2.tar.bz2"),
-			 uris[0]);
+                         uris[0]);
     CPPUNIT_ASSERT_EQUAL(std::string("http://httphost/aria2-0.5.2.tar.bz2"),
-			 uris[1]);
+                         uris[1]);
     // See numConcurrentCommand is 1 because of maxconnections attribute.
     CPPUNIT_ASSERT_EQUAL((unsigned int)1, group->getNumConcurrentCommand());
   }
